@@ -17,7 +17,7 @@ from web.kernel.types import ConfAble, GenConfig, AppNameAble, Environment, EnvA
     IScheduler, ChanAble, SocketConf, TaskEvent, SharedState, SignalType, call_signals
 
 
-class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble, EnvAble):
+class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble):
     _transports: List[Transport]
     name: str
     _environment: Environment
@@ -122,6 +122,10 @@ class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble, EnvAble
 
         cheat(self, ConfAble, self.conf)
 
+        await self._environment.init()
+        await call_signals(self, SignalType.BEFORE_APP_RUN, app=self)
+        await self._environment.shutdown()
+
         if multiprocessing:
             self.manager.add_isolate_list(self._create_transport_isolates(workers=os.cpu_count() if fast else None))
             # tasks.extend(self.manager.perform())
@@ -153,8 +157,7 @@ class WebApp(Generic[GenConfig], ConfAble[GenConfig], SigAble, ChanAble, EnvAble
         loop.add_signal_handler(SIGINT, lambda: asyncio.create_task(sig_handler()))
         loop.add_signal_handler(SIGTERM, lambda: asyncio.create_task(sig_handler()))
 
-        await self.env.init()
-        await call_signals(self, SignalType.BEFORE_APP_RUN, app=self)
+        await self._environment.init()
         await asyncio.wait(tasks)
         await self._environment.shutdown()
 
