@@ -737,11 +737,11 @@ class Environment(ConfAble, AppNameAble, ChanAble, SharedStateAble):
                 self._resources.append(res)
 
     async def init(self):
-        cheat(self, AppNameAble, self.app_name)
-        cheat(self, ChanAble, self.channel)
         for res in self._resources:
-            cheat(res, AppNameAble, self.app_name)
-            cheat(res, ConfAble, self.conf)
+            loguru.logger.warning(os.getpid())
+            cheat(res, AppNameAble, self.app_name,nested=False)
+            cheat(res, ConfAble, self.conf,nested=False)
+            cheat(res, ChanAble, self.channel,nested=False)
             await res.init()
 
     async def shutdown(self):
